Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp	(revision 54794)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp	(revision 54795)
@@ -2422,6 +2422,6 @@
         if (attachment.GetType() == KDeviceType_HardDisk)
         {
-            /* Get the attachment medium: */
-            const CMedium medium = attachment.GetMedium();
+            /* Get the attachment medium base: */
+            const CMedium medium = attachment.GetMedium().GetBase();
             /* Update the map with this medium if necessary: */
             const QString strKeyId = medium.GetProperty("CRYPT/KeyId");
